import { AbstractPowerSyncDatabase, AbstractStreamingSyncImplementation, PowerSyncBackendConnector, BucketStorageAdapter, PowerSyncDatabaseOptions, PowerSyncCloseOptions } from '@journeyapps/powersync-sdk-common';
export interface WebPowerSyncFlags {
    /**
     * Enables multi tab support
     */
    enableMultiTabs?: boolean;
    /**
     * Open in SSR placeholder mode. DB operations and Sync operations will be a No-op
     */
    ssrMode?: boolean;
    /**
     * Externally unload open PowerSync database instances when the window closes.
     * Setting this to `true` requires calling `close` on all open PowerSyncDatabase
     * instances before the window unloads
     */
    externallyUnload?: boolean;
}
export interface WebPowerSyncDatabaseOptions extends PowerSyncDatabaseOptions {
    flags?: WebPowerSyncFlags;
}
export declare class PowerSyncDatabase extends AbstractPowerSyncDatabase {
    protected options: WebPowerSyncDatabaseOptions;
    protected unloadListener?: () => Promise<void>;
    constructor(options: WebPowerSyncDatabaseOptions);
    _initialize(): Promise<void>;
    /**
     * Closes the database connection.
     * By default the sync stream client is only disconnected if
     * multiple tabs are not enabled.
     */
    close(options?: PowerSyncCloseOptions): Promise<void>;
    connect(connector: PowerSyncBackendConnector): Promise<void>;
    protected generateBucketStorageAdapter(): BucketStorageAdapter;
    protected generateSyncStreamImplementation(connector: PowerSyncBackendConnector): AbstractStreamingSyncImplementation;
}
