var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AbstractPowerSyncDatabase, SqliteBucketStorage, DEFAULT_POWERSYNC_CLOSE_OPTIONS } from '@journeyapps/powersync-sdk-common';
import { WebRemote } from './sync/WebRemote';
import { SharedWebStreamingSyncImplementation } from './sync/SharedWebStreamingSyncImplementation';
import { SSRStreamingSyncImplementation } from './sync/SSRWebStreamingSyncImplementation';
import { WebStreamingSyncImplementation } from './sync/WebStreamingSyncImplementation';
export class PowerSyncDatabase extends AbstractPowerSyncDatabase {
    constructor(options) {
        super(options);
        this.options = options;
        const { flags } = this.options;
        if ((flags === null || flags === void 0 ? void 0 : flags.enableMultiTabs) && !flags.externallyUnload) {
            this.unloadListener = () => this.close({ disconnect: false });
            window.addEventListener('unload', this.unloadListener);
        }
    }
    _initialize() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    /**
     * Closes the database connection.
     * By default the sync stream client is only disconnected if
     * multiple tabs are not enabled.
     */
    close(options = DEFAULT_POWERSYNC_CLOSE_OPTIONS) {
        var _a, _b;
        if (this.unloadListener) {
            window.removeEventListener('unload', this.unloadListener);
        }
        return super.close({
            // Don't disconnect by default if multiple tabs are enabled
            disconnect: (_a = options.disconnect) !== null && _a !== void 0 ? _a : !((_b = this.options.flags) === null || _b === void 0 ? void 0 : _b.enableMultiTabs)
        });
    }
    connect(connector) {
        /**
         * Using React strict mode might cause calls to connect to fire multiple times
         * Connect is wrapped inside a lock in order to prevent race conditions internally between multiple
         * connection attempts.
         */
        return navigator.locks.request(`connection-lock-${this.options.database.name}`, () => super.connect(connector));
    }
    generateBucketStorageAdapter() {
        return new SqliteBucketStorage(this.database, AbstractPowerSyncDatabase.transactionMutex);
    }
    generateSyncStreamImplementation(connector) {
        const remote = new WebRemote(connector);
        const syncOptions = Object.assign(Object.assign({}, this.options), { adapter: this.bucketStorageAdapter, remote, uploadCrud: () => __awaiter(this, void 0, void 0, function* () {
                yield this.waitForReady();
                yield connector.uploadData(this);
            }), identifier: this.options.database.name });
        const { flags } = this.options;
        switch (true) {
            case flags === null || flags === void 0 ? void 0 : flags.ssrMode:
                return new SSRStreamingSyncImplementation(syncOptions);
            case flags === null || flags === void 0 ? void 0 : flags.enableMultiTabs:
                return new SharedWebStreamingSyncImplementation(syncOptions);
            default:
                return new WebStreamingSyncImplementation(syncOptions);
        }
    }
}
//# sourceMappingURL=PowerSyncDatabase.js.map