import Logger from 'js-logger';
/**
 * Broadcasts logs to all clients
 */
export class BroadcastLogger {
    constructor(clients) {
        this.clients = clients;
        this.TRACE = Logger.TRACE;
        this.DEBUG = Logger.DEBUG;
        this.INFO = Logger.INFO;
        this.TIME = Logger.TIME;
        this.WARN = Logger.WARN;
        this.ERROR = Logger.ERROR;
        this.OFF = Logger.OFF;
    }
    trace(...x) {
        console.trace(...x);
        this.clients.forEach((p) => p.clientProvider.trace(...x));
    }
    debug(...x) {
        console.debug(...x);
        this.clients.forEach((p) => p.clientProvider.debug(...x));
    }
    info(...x) {
        console.info(...x);
        this.clients.forEach((p) => p.clientProvider.info(...x));
    }
    log(...x) {
        console.log(...x);
        this.sanitizeArgs(x, (params) => this.clients.forEach((p) => p.clientProvider.log(...params)));
    }
    warn(...x) {
        console.warn(...x);
        this.sanitizeArgs(x, (params) => this.clients.forEach((p) => p.clientProvider.warn(...params)));
    }
    error(...x) {
        console.error(...x);
        this.sanitizeArgs(x, (params) => this.clients.forEach((p) => p.clientProvider.error(...params)));
    }
    time(label) {
        console.time(label);
        this.clients.forEach((p) => p.clientProvider.time(label));
    }
    timeEnd(label) {
        console.timeEnd(label);
        this.clients.forEach((p) => p.clientProvider.timeEnd(label));
    }
    setLevel(level) {
        // Levels are not adjustable on this level.
    }
    getLevel() {
        // Levels are not adjustable on this level.
        return Logger.INFO;
    }
    enabledFor(level) {
        // Levels are not adjustable on this level.
        return true;
    }
    /**
     * Guards against any logging errors.
     * We don't want a logging exception to cause further issues upstream
     */
    sanitizeArgs(x, handler) {
        const sanitizedParams = x.map((param) => {
            try {
                // Try and clone here first. If it fails it won't be passable over a MessagePort
                return structuredClone(x);
            }
            catch (ex) {
                console.error(ex);
                return 'Could not serialize log params. Check shared worker logs for more details.';
            }
        });
        return handler(...sanitizedParams);
    }
}
//# sourceMappingURL=BroadcastLogger.js.map